.. currentmodule:: sardana.pool.poolonedexpchannel

.. _sardana-1d-api:

=============================
1D channel API reference
=============================

.. todo:: document 1D channel API reference

.. seealso:: 
    
    :ref:`sardana-1d-overview`
        the 1D experiment channel overview 
    
    :class:`~sardana.tango.pool.OneDExpChannel.OneDExpChannel`
        the 1D experiment channel tango device :term:`API`

..    :class:`~sardana.pool.poolonedexpchannel.Pool1DExpChannel`
..        the 1D experiment channel class :term:`API`
